==> regina-normal_5.0.orig.tar.gz: regina-5.0/testsuite/census/testcensus.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Test Suite                                                            *
 *                                                                        *
 *  Copyright (c) 1999-2016, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/**
 * This file allows all tests from this directory to be added to
 * the overall test runner, without requiring any further inclusion
 * of headers that define the specific corresponding test fixtures.
 *
 * The routines declared below (which should add tests to the given
 * test runner) should be implemented in this directory and then called
 * from the top-level test suite directory.
 */

#include <cppunit/ui/text/TestRunner.h>

void addNCensus(CppUnit::TextUi::TestRunner& runner);
void addNFacePairing(CppUnit::TextUi::TestRunner& runner);
void addDim2Census(CppUnit::TextUi::TestRunner& runner);
void addDim2EdgePairing(CppUnit::TextUi::TestRunner& runner);
void addDim4Census(CppUnit::TextUi::TestRunner& runner);
void addDim4FacetPairing(CppUnit::TextUi::TestRunner& runner);

==> regina-normal_5.1.orig.tar.gz: regina-5.1/testsuite/census/testcensus.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Test Suite                                                            *
 *                                                                        *
 *  Copyright (c) 1999-2016, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/**
 * This file allows all tests from this directory to be added to
 * the overall test runner, without requiring any further inclusion
 * of headers that define the specific corresponding test fixtures.
 *
 * The routines declared below (which should add tests to the given
 * test runner) should be implemented in this directory and then called
 * from the top-level test suite directory.
 */

#include <cppunit/ui/text/TestRunner.h>

void addCensus3(CppUnit::TextUi::TestRunner& runner);
void addFacetPairing3(CppUnit::TextUi::TestRunner& runner);
void addCensus2(CppUnit::TextUi::TestRunner& runner);
void addFacetPairing2(CppUnit::TextUi::TestRunner& runner);
void addCensus4(CppUnit::TextUi::TestRunner& runner);
void addFacetPairing4(CppUnit::TextUi::TestRunner& runner);
